==> haskell-ini-0.3.6-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ini
version: 0.3.6
id: ini-0.3.6-10Y1cVuQkYo7GFokzo62c4
key: ini-0.3.6-10Y1cVuQkYo7GFokzo62c4
license: BSD-3-Clause
copyright: 2013 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
homepage: http://github.com/chrisdone/ini
synopsis: Quick and easy configuration files in the INI format.
description:
    Quick and easy configuration files in the INI format.
category: Data, Configuration
abi: bc3d6f06d40194fab9a034b8303a22d9
exposed: True
exposed-modules:
    Data.Ini
import-dirs: /usr/lib/ghc-8.4.3/site-local/ini-0.3.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/ini-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/ini-0.3.6
hs-libraries: HSini-0.3.6-10Y1cVuQkYo7GFokzo62c4
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH
    text-1.2.3.0 unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-2rSZNTl4Hzq7SdjVOGnWBH=8e6e77bd73af6a8072fdc40742d8861e
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html: /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ini-0.3.6-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ini.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ini
version: 0.3.6
id: ini-0.3.6-2OyzhSnYUZO73PQoAq2C9M
key: ini-0.3.6-2OyzhSnYUZO73PQoAq2C9M
license: BSD-3-Clause
copyright: 2013 Chris Done
maintainer: chrisdone@gmail.com
author: Chris Done
homepage: http://github.com/chrisdone/ini
synopsis: Quick and easy configuration files in the INI format.
description:
    Quick and easy configuration files in the INI format.
category: Data, Configuration
abi: 32fbd3da912623f847dfbdc7007a7ae3
exposed: True
exposed-modules:
    Data.Ini
import-dirs: /usr/lib/ghc-8.4.3/site-local/ini-0.3.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/ini-0.3.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/ini-0.3.6
hs-libraries: HSini-0.3.6-2OyzhSnYUZO73PQoAq2C9M
depends:
    base-4.11.1.0 attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq
    text-1.2.3.0 unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq=07053c5359c7530f0cb8534ff020b021
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html: /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
